#ifndef INCLUDED_SimpleSoccer_h_
#define INCLUDED_SimpleSoccer_h_

#include "Behaviors/BehaviorBase.h"
#include "Motion/MotionManager.h"
#include "Behaviors/Controls/FileBrowserControl.h"
#include "Motion/MotionSequenceMC.h"
#include "Motion/EmergencyStopMC.h"
#include "Motion/LedMC.h"
#include "SoundPlay/SoundManager.h"
#include "Motion/MMAccessor.h"
#include "Shared/TimeET.h"
#include "Shared/Config.h"
#include <string>
#include "WorldMap.h"
#include "DataTypes.h"
#include "States.h"

//various player types
const int GOALIE_ID = 0; //const Goalie
const int ATTACKER_ID = 10;//conts Attacker Drop Chest
const int DEFENDER_ID = 3;
const unsigned int VIS_TIMER_ID = 1111;			//this time is used to measure the length of time the ball has not been seen
//desired area of ball to trigger action
const float GOALIE_DESIRED_AREA = 0.03491717; //const Goalie
const float ATTACKER_DESIRED_AREA = 2.0;//conts Attacker
//const float ATTACKER_DESIRED_AREA = 0.02091717;//conts Attacker



AIBO_STATES subState;

const int bDEBUG = false;

//! A simple behavior to chase after any objects seen by the vision system
class SimpleSoccer : public BehaviorBase {
public:
	//!constructor
	SimpleSoccer()
		:	BehaviorBase("SimpleSoccer"), player_type(ATTACKER_ID), previous_area(0.0), desired_area(0.0), prior_mode(PLAY_PAUSED), currGState(INITIAL),  
				tColor(BLUE), isColorSet(true), isPosSet(false), isTimerOn(false), time_in_state(0), AreaCounter(0), PrevAreaCounter(0), motion_waiting(false), time_lost(0), ballArea(0.0),
				headpointer_id(MotionManager::invalid_MC_ID), walker_id(MotionManager::invalid_MC_ID), leds_id(MotionManager::invalid_MC_ID), isBtnPressed(false)
						
	{
			sndman->PlayFile("scooby.wav");
	

	}
	//!destructor
	virtual ~SimpleSoccer() {}

	//! adds a headpointer and a walker, and a listens for vision events
	virtual void DoStart();

	//! removes motion commands and stops listening
	virtual void DoStop();

	//! sets the head to point at the object and sets the body to move where the head points
	virtual void processEvent(const EventBase& event);

	void CenterHeadOnBall(float x, float y);
			
	static std::string getClassDescription() { return "Follows ball with head and walks whereever the head is pointing"; }
	virtual std::string getDescription() const { return getClassDescription(); }

protected:
	int player_type;	//PlayerType
	float previous_area; //previous Area
	float desired_area;
	//int play_mode;
	AIBO_STATES prior_mode;
	GAME_STATES currGState;	
	TEAM_COLOR tColor;
	bool isColorSet;
	bool isPosSet;
	bool isTimerOn;
	int time_in_state;			//used to count iterations of the timer.
	int AreaCounter;
	int PrevAreaCounter;
	bool motion_waiting;
	int time_lost;
	
	float ballArea;
	MotionManager::MC_ID headpointer_id; //!< a HeadPointerMC object
	MotionManager::MC_ID walker_id;      //!< a WalkMC object
	MotionManager::MC_ID leds_id;		//
	//WorldMap * pWorld;					//the worldmap
	SharedObject<LedMC> leds_mc;
	
	bool isBtnPressed;

	float area1;
	float horz1;
	float vert1;
	float area0;
	float horz0;
	float vert0;
	float cur_time;
	float see_time;
	
	//int MY_ID = 1;					

	void PanHead();

	
};

#endif

